==> genius-0.7.2.tar.bz2: genius-0.7.2/mpfr/tests/tsgn.c <==
/* tsgn -- Test for the sign of a floating point number.

Copyright 2003 Free Software Foundation.
Contributed by the Spaces project, INRIA Lorraine.

This file is part of the MPFR Library.

The MPFR Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or (at your
option) any later version.

The MPFR Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public License
along with the MPFR Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. */

#include <stdio.h>
#include <stdlib.h>

#include "mpfr-test.h"

static void
check_special(void)
{
  mpfr_t x;
  int ret = 0;

  mpfr_init(x);
  MPFR_SET_ZERO(x);
  if ((mpfr_sgn) (x) != 0)
    {
      printf("Sgn error for 0.\n");
      ret = 1;
    }
  MPFR_SET_INF(x);
  MPFR_SET_POS(x);
  if ((mpfr_sgn) (x) != 1)
    {
      printf("Sgn error for +Inf.\n");
      ret = 1;
    }
  MPFR_SET_INF(x);
  MPFR_SET_NEG(x);
  if ((mpfr_sgn) (x) != -1)
    {
      printf("Sgn error for -Inf.\n");
      ret = 1;
    }
  mpfr_clear(x);
  if (ret)
    exit(ret);
}

static void
check_sgn(void)
{
  mpfr_t x;
  int i, s1, s2;

  mpfr_init(x);
  for(i = 0 ; i < 100 ; i++)
    {
      mpfr_random(x);
      if (i&1)
	{
	  MPFR_SET_POS(x);
	  s2 = 1;
	}
      else
	{
	  MPFR_SET_NEG(x);
	  s2 = -1;
	}
      s1 = mpfr_sgn(x);
      if (s1 < -1 || s1 > 1)
	{
	  printf("Error for sgn: out of range.\n");
	  goto lexit;
	}
      else if (MPFR_IS_NAN(x) || MPFR_IS_ZERO(x))
	{
	  if (s1 != 0)
	    {
	      printf("Error for sgn: Nan or Zero should return 0.\n");
	      goto lexit;
	    }
	}
      else if (s1 != s2)
	{
	  printf("Error for sgn. Return %d instead of %d.\n", s1, s2);
	  goto lexit;
	}
    }
  mpfr_clear(x);
  return;

 lexit:
  mpfr_clear(x);
  exit(1);
}

int
main (int argc, char *argv[])
{
  tests_start_mpfr ();

  check_special ();
  check_sgn ();

  tests_end_mpfr ();
  return 0;
}

==> genius-0.7.3.tar.bz2: genius-0.7.3/mpfr/tests/tsgn.c <==
/* tsgn -- Test for the sign of a floating point number.

Copyright 2003 Free Software Foundation.
Contributed by the Spaces project, INRIA Lorraine.

This file is part of the MPFR Library.

The MPFR Library is free software; you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License as published by
the Free Software Foundation; either version 2.1 of the License, or (at your
option) any later version.

The MPFR Library is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
License for more details.

You should have received a copy of the GNU Lesser General Public License
along with the MPFR Library; see the file COPYING.LIB.  If not, write to
the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
MA 02111-1307, USA. */

#include <stdio.h>
#include <stdlib.h>

#include "mpfr-test.h"

static void
check_special(void)
{
  mpfr_t x;
  int ret = 0;

  mpfr_init(x);
  MPFR_SET_ZERO(x);
  if (mpfr_sgn(x) != 0)
    {
      printf("Sgn error for 0.\n");
      ret = 1;
    }
  MPFR_SET_INF(x);
  MPFR_SET_POS(x);
  if (mpfr_sgn(x) != 1)
    {
      printf("Sgn error for +Inf.\n");
      ret = 1;
    }
  MPFR_SET_INF(x);
  MPFR_SET_NEG(x);
  if (mpfr_sgn(x) != -1)
    {
      printf("Sgn error for -Inf.\n");
      ret = 1;
    }
  mpfr_clear(x);
  if (ret)
    exit(ret);
}

static void
check_sgn(void)
{
  mpfr_t x;
  int i, s1, s2;

  mpfr_init(x);
  for(i = 0 ; i < 100 ; i++)
    {
      mpfr_random(x);
      if (i&1)
	{
	  MPFR_SET_POS(x);
	  s2 = 1;
	}
      else
	{
	  MPFR_SET_NEG(x);
	  s2 = -1;
	}
      s1 = mpfr_sgn(x);
      if (s1 < -1 || s1 > 1)
	{
	  printf("Error for sgn: out of range.\n");
	  goto lexit;
	}
      else if (MPFR_IS_NAN(x) || MPFR_IS_ZERO(x))
	{
	  if (s1 != 0)
	    {
	      printf("Error for sgn: Nan or Zero should return 0.\n");
	      goto lexit;
	    }
	}
      else if (s1 != s2)
	{
	  printf("Error for sgn. Return %d instead of %d.\n", s1, s2);
	  goto lexit;
	}
    }
  mpfr_clear(x);
  return;

 lexit:
  mpfr_clear(x);
  exit(1);
}

int
main (int argc, char *argv[])
{
  tests_start_mpfr ();

  check_special ();
  check_sgn ();

  tests_end_mpfr ();
  return 0;
}
